@@ -28,6 +28,7 @@
 #include "braille.h"
 #include "baumbrl.h"
 #include "alvabrl.h"
+#include "handybrl.h"
 #ifdef BRLTTY_SUPPORT
 #include "ttybrl.h"
 #endif
@@ -51,27 +52,34 @@ BRLDEV_INFO   SupportedDevices[] = {
   {"ALVA380", "ALVABRAILLE 380"},
   {"ALVA544", "ALVABRAILLE 544"},
   {"ALVA570", "ALVABRAILLE 570"},
-  {"BRLTTY", "BRLTTY's BrlAPI"}
+  {"BRLTTY", "BRLTTY's BrlAPI"},
+  {"HTBRW", "HandyTech Braille Wave"},
+  {"HTBL2", "HandyTech Braillino"},
+  {"HTBS4", "HandyTech Braille Star 40"},
+  {"HTBS8", "HandyTech Braille Star 80"},
+  {"HTMB2", "HandyTech Modular 24"},
+  {"HTMB4", "HandyTech Modular 44"},
+  {"HTMB8", "HandyTech Modular 84"}
 
  };
 
 
-static BRL_DEVICE*						CurrentDevice = NULL;
-static unsigned char* 					Dots = NULL;
+static BRL_DEVICE* CurrentDevice = NULL;
+static unsigned char* Dots = NULL;
 
-/* static short 										CursorShape = 0x0C;		 dot 7/8 */
-/* static short 										CursorMask = 0x0C;       dot 7/8 */
-/* static short 										BrailleStyle = 8;             8 dot Braille */
-/* static short 										AttrStyle = 0;					 ... */
-/* static short 										CursorPos = -1;				 ... no cursor */
-/* static char* 									Text = NULL; */
-/* static unsigned long* 					Attrs = NULL; */
+/* static short CursorShape = 0x0C;		 dot 7/8 */
+/* static short CursorMask = 0x0C;       dot 7/8 */
+/* static short BrailleStyle = 8;             8 dot Braille */
+/* static short AttrStyle = 0;					 ... */
+/* static short CursorPos = -1;				 ... no cursor */
+/* static char* Text = NULL; */
+/* static unsigned long* Attrs = NULL; */
 
 
 
-/* static unsigned char 						*TranslationTable = NULL;	  !!! consider MBCS !!! */
+/* static unsigned char *TranslationTable = NULL;	  !!! consider MBCS !!! */
 
-static BRAILLE_EVENT_PROC		ClientEventProc = NULL;
+static BRAILLE_EVENT_PROC ClientEventProc = NULL;
 
 /* Deviceless Functions */
 
@@ -221,6 +229,20 @@ int brl_open_device (char *DeviceName, int Port, BRAILLE_EVENT_PROC EventProc)
 			/* rv = tsc_open_device (DeviceName, Port, CurrentDevice, deviceCallback);		 */
 		}
 
+		/* HANDYTECH displays */
+		else if (strcmp("HTBRW", DeviceName) == 0 ||
+			 strcmp("HTBL2", DeviceName) == 0 ||
+			 strcmp("HTBS4", DeviceName) == 0 ||
+			 strcmp("HTBS8", DeviceName) == 0 ||
+			 strcmp("HTMB2", DeviceName) == 0 ||
+			 strcmp("HTMB4", DeviceName) == 0 ||
+			 strcmp("HTMB8", DeviceName) == 0
+			)
+		{
+			rv =  handy_brl_open_device(DeviceName, Port, DeviceCallback, CurrentDevice);
+		}
+
+
 		/* else if */
 		else
 		{
