@@ -69,6 +69,7 @@ this will be the same for the entire collention of zoomers, so for the entire sc
 schema = a collection of zoomers
 */
 gboolean zoom_factor_changed = TRUE;
+gboolean zoom_factor_was_changed = FALSE; /* does the same thing as zoom_factor_changed but only for the zoom factor*/
 
 static gboolean cursor		= TRUE;
 static gboolean cursor_scale	= TRUE;
@@ -86,6 +87,7 @@ gboolean	crosswire_clip  = FALSE;/*whenever to insert the cursor over the crossw
 MagRectangle source_rect;
 MagRectangle target_rect;
 static MagRectangle rect;
+static MagRectangle mouse_tracked_roi;
 
 static MagRectangle roi_viewport;
 extern MagRectangle zp_rect;
@@ -304,6 +306,7 @@ mag_zoomer_set_params_zoom_factor (MagZoomer *mag_zoomer,
 	/*check if the zoom factor was changed - 
 	needed for the focus/mouse tracking logic*/
 		zoom_factor_changed = TRUE;
+		zoom_factor_was_changed = TRUE;
 	    if ( (strncasecmp ( "+", zoom_factor_x, 1) != 0) &&
 		 (strncasecmp ( "-", zoom_factor_x, 1) != 0)	     
 	       ) 
@@ -316,6 +319,7 @@ mag_zoomer_set_params_zoom_factor (MagZoomer *mag_zoomer,
 	/*check if the zoom factor was changed - 
 	needed for the focus/mouse tracking logic*/
 	    	zoom_factor_changed = TRUE;
+		zoom_factor_was_changed = TRUE;
 	    if ( (strncasecmp ( "+", zoom_factor_y, 1) != 0) &&
 		 (strncasecmp ( "-", zoom_factor_y, 1) != 0)	     
 	       ) 
@@ -360,19 +364,36 @@ mag_zoomer_set_params_contrast (MagZoomer *mag_zoomer,
 	mag_zoomer->params.contrast = atof (contrast);	
 }
 
+gboolean
+check_for_focus_tracking_none  (MagZoomer *mag_zoomer)
+{
+    if((mag_zoomer->params.alignment.x == MAG_ALIGN_NONE) &&
+       (mag_zoomer->params.alignment.y == MAG_ALIGN_NONE) && zoom_factor_was_changed)
+       return TRUE;
+    else
+	return FALSE;
+}
+
 void 
 mag_zoomer_set_params_tracking (MagZoomer *mag_zoomer, 
 			    	gchar     *tracking)
 {
 	if  (g_strcasecmp(tracking, "focus")  == 0) 
 	{
-	    mag_zoomer->params.tracking = MAG_TRACKING_FOCUS;	
+	    if (check_for_focus_tracking_none (mag_zoomer))
+		mag_zoomer->params.tracking = MAG_TRACKING_MOUSE;	
+	    else
+	    	mag_zoomer->params.tracking = MAG_TRACKING_FOCUS;	
 	}
 	else
 	{
 	    if  (g_strcasecmp(tracking, "mouse")  == 0) 
 	    {
 		mag_zoomer->params.tracking = MAG_TRACKING_MOUSE;
+		mouse_tracked_roi.left = mag_zoomer->region_of_interest.left;
+		mouse_tracked_roi.top = mag_zoomer->region_of_interest.top;
+		mouse_tracked_roi.width = mag_zoomer->region_of_interest.width;
+		mouse_tracked_roi.height = mag_zoomer->region_of_interest.height;
 	    }
 	    else
 	    {
@@ -529,6 +550,8 @@ mag_zoomer_set_ROI_left (MagZoomer *mag_zoomer,
 {
 	int roi_left = atoi (ROILeft);
 
+	if (check_for_focus_tracking_none (mag_zoomer))
+	    roi_left = mouse_tracked_roi.left;
 	if ( roi_left > source_rect.left)
 	    mag_zoomer->region_of_interest.left = roi_left;
 	else
@@ -541,6 +564,8 @@ mag_zoomer_set_ROI_top (MagZoomer *mag_zoomer,
 {
 	int roi_top = atoi (ROITop);
 
+	if (check_for_focus_tracking_none (mag_zoomer))
+	    roi_top = mouse_tracked_roi.top;
 	if ( roi_top > source_rect.top)
 	    mag_zoomer->region_of_interest.top = roi_top;
 	else
@@ -553,7 +578,9 @@ mag_zoomer_set_ROI_width (MagZoomer *mag_zoomer,
 			  gchar     *ROIWidth)
 {
 	int roi_width = atoi (ROIWidth);
-
+	
+	if (check_for_focus_tracking_none (mag_zoomer))
+	    roi_width = mouse_tracked_roi.width;
 	if ( roi_width < source_rect.width)
 	    mag_zoomer->region_of_interest.width = roi_width;
 	else
@@ -565,7 +592,12 @@ mag_zoomer_set_ROI_height (MagZoomer *mag_zoomer,
 			   gchar     *ROIHeight)
 {
 	int roi_height = atoi (ROIHeight);
-
+	
+	if (check_for_focus_tracking_none (mag_zoomer))
+	{
+	    roi_height = mouse_tracked_roi.height;
+	    zoom_factor_was_changed = FALSE;
+	}
 	if ( roi_height < source_rect.height)
     	    mag_zoomer->region_of_interest.height = roi_height;
 	else
@@ -872,11 +904,11 @@ mag_zoomers_set_cursor_scale_on_off (gchar *cursor_scale_on_off)
 	     (g_strcasecmp(cursor_scale_on_off, "false") == 0) ||
 	     (g_strcasecmp(cursor_scale_on_off, "0")     == 0))
 	{
-	    cursor_scale = FALSE;
+	    cursor_scale = TRUE;
 	}
 	else
 	{
-	    cursor_scale = TRUE;
+	    cursor_scale = FALSE;
 	}
 
 	if (cursor_scale)
